/*
** dns_services.h              DNS/Hesiod Services map access definitions
**
** Copyright (c) 1993 Signum Support AB, Sweden
**
** This file is part of the NYS Library.
**
** The NYS Library is free software; you can redistribute it and/or
** modify it under the terms of the GNU Library General Public License as
** published by the Free Software Foundation; either version 2 of the
** License, or (at your option) any later version.
**
** The NYS Library is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Library General Public License for more details.
** 
** You should have received a copy of the GNU Library General Public
** License along with the NYS Library; see the file COPYING.LIB.  If
** not, write to the Free Software Foundation, Inc., 675 Mass Ave,
** Cambridge, MA 02139, USA.
**
** Author: Peter Eriksson <pen@signum.se>
*/

#ifndef __DNSLIB_SERVICES_H__
#define __DNSLIB_SERVICES_H__

#include <sys/types.h>
#include <netdb.h>

extern void dns_setservent(int stayopen);
extern void dns_endservent(void);
extern struct servent *dns_getservent(void);
extern struct servent *dns_getservbyname(const char *name,
					 const char *protocol);
extern struct servent *dns_getservbyport(int port,
					 const char *protocol);

#endif
